==> haskell-network-simple-0.4.5-198.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-network-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-simple
version:              0.4.5
visibility:           public
id:                   network-simple-0.4.5-Jw1D5XUDYXLDt2ZMwnITDt
key:                  network-simple-0.4.5-Jw1D5XUDYXLDt2ZMwnITDt
license:              BSD-3-Clause
copyright:            Copyright (c) Renzo Carbonara 2013-2019
maintainer:           renλren.zone
author:               Renzo Carbonara
homepage:             https://github.com/k0001/network-simple
synopsis:             Simple network sockets usage patterns.
description:
    This module exports functions that abstract simple network socket
    usage patterns.

    See the @changelog.md@ file in the source distribution to learn about any
    important changes between versions.

category:             Network
abi:                  3c8d9a3bcb6c7bfe6054439a9a0ff3e3
exposed:              True
exposed-modules:      Network.Simple.TCP
hidden-modules:       Network.Simple.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/network-simple-0.4.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/network-simple-0.4.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/network-simple-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-simple
hs-libraries:         HSnetwork-simple-0.4.5-Jw1D5XUDYXLDt2ZMwnITDt
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe
    network-bsd-2.8.1.0-tw2oRH0FuUAjhgeHdG5Oa
    safe-exceptions-0.1.7.4-77vNmGqKu2OFQzf0vTZZHI
    socks-0.6.1-rRpuMt58ZnKbxieNUj35R transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-network-simple/html/network-simple.haddock

haddock-html:         /usr/share/doc/haskell-network-simple/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-simple-0.4.5-199-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-network-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-simple
version:              0.4.5
visibility:           public
id:                   network-simple-0.4.5-Bl5qE2Kj9GY3poJHtM8cjJ
key:                  network-simple-0.4.5-Bl5qE2Kj9GY3poJHtM8cjJ
license:              BSD-3-Clause
copyright:            Copyright (c) Renzo Carbonara 2013-2019
maintainer:           renλren.zone
author:               Renzo Carbonara
homepage:             https://github.com/k0001/network-simple
synopsis:             Simple network sockets usage patterns.
description:
    This module exports functions that abstract simple network socket
    usage patterns.

    See the @changelog.md@ file in the source distribution to learn about any
    important changes between versions.

category:             Network
abi:                  c05ad919847834563ac9c1a617cd1017
exposed:              True
exposed-modules:      Network.Simple.TCP
hidden-modules:       Network.Simple.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/network-simple-0.4.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/network-simple-0.4.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/network-simple-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-simple
hs-libraries:         HSnetwork-simple-0.4.5-Bl5qE2Kj9GY3poJHtM8cjJ
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ
    network-bsd-2.8.1.0-D7anFlGqSCnK99qTn3SolU
    safe-exceptions-0.1.7.4-77vNmGqKu2OFQzf0vTZZHI
    socks-0.6.1-3B1JoDmDrZS95uSSHv0NVP transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-network-simple/html/network-simple.haddock

haddock-html:         /usr/share/doc/haskell-network-simple/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
